@@ -1,8 +1,9 @@
 /*
- * encoding.h : interface for the encoding conversion functions needed for
- *              XML
+ * Summary: interface for the encoding conversion functions
+ * Description: interface for the encoding conversion functions needed for
+ *              XML basic encoding and iconv() support.
  *
- * Related specs: 
+ * Related specs are
  * rfc2044        (UTF-8 and UTF-16) F. Yergeau Alis Technologies
  * [ISO-10646]    UTF-8 and UTF-16 in Annexes
  * [ISO-8859-1]   ISO Latin-1 characters codes.
@@ -13,9 +14,9 @@
  * [US-ASCII]     Coded Character Set--7-bit American Standard Code for
  *                Information Interchange, ANSI X3.4-1986.
  *
- * See Copyright for the status of this software.
+ * Copy: See Copyright for the status of this software.
  *
- * daniel@veillard.com
+ * Author: Daniel Veillard
  */
 
 #ifndef __XML_CHAR_ENCODING_H__
@@ -30,23 +31,26 @@
 extern "C" {
 #endif
 
-/**
+/*
  * xmlCharEncoding:
  *
  * Predefined values for some standard encodings.
- * Libxml don't do beforehand translation on UTF8, ISOLatinX.
- * It also support UTF16 (LE and BE) by default.
+ * Libxml does not do beforehand translation on UTF8 and ISOLatinX.
+ * It also supports ASCII, ISO-8859-1, and UTF16 (LE and BE) by default.
  *
  * Anything else would have to be translated to UTF8 before being
  * given to the parser itself. The BOM for UTF16 and the encoding
  * declaration are looked at and a converter is looked for at that
- * point. If not found the parser stops here as asked by the XML REC
- * Converter can be registered by the user using xmlRegisterCharEncodingHandler
+ * point. If not found the parser stops here as asked by the XML REC. A
+ * converter can be registered by the user using xmlRegisterCharEncodingHandler
  * but the current form doesn't allow stateful transcoding (a serious
  * problem agreed !). If iconv has been found it will be used
  * automatically and allow stateful transcoding, the simplest is then
- * to be sure to enable icon and to provide iconv libs for the encoding
+ * to be sure to enable iconv and to provide iconv libs for the encoding
  * support needed.
+ *
+ * Note that the generic "UTF-16" is not a predefined value.  Instead, only
+ * the specific UTF-16LE and UTF-16BE are present.
  */
 typedef enum {
     XML_CHAR_ENCODING_ERROR=   -1, /* No char encoding detected */
@@ -85,10 +89,10 @@ typedef enum {
  * Take a block of chars in the original encoding and try to convert
  * it to an UTF-8 block of chars out.
  *
- * Returns the number of byte written, or -1 by lack of space, or -2
+ * Returns the number of bytes written, -1 if lack of space, or -2
  *     if the transcoding failed.
  * The value of @inlen after return is the number of octets consumed
- *     as the return value is positive, else unpredictiable.
+ *     if the return value is positive, else unpredictiable.
  * The value of @outlen after return is the number of octets consumed.
  */
 typedef int (* xmlCharEncodingInputFunc)(unsigned char *out, int *outlen,
@@ -102,16 +106,16 @@ typedef int (* xmlCharEncodingInputFunc)(unsigned char *out, int *outlen,
  * @in:  a pointer to an array of UTF-8 chars
  * @inlen:  the length of @in
  *
- * Take a block of UTF-8 chars in and try to convert it to an other
+ * Take a block of UTF-8 chars in and try to convert it to another
  * encoding.
  * Note: a first call designed to produce heading info is called with
  * in = NULL. If stateful this should also initialize the encoder state.
  *
- * Returns the number of byte written, or -1 by lack of space, or -2
+ * Returns the number of bytes written, -1 if lack of space, or -2
  *     if the transcoding failed.
  * The value of @inlen after return is the number of octets consumed
- *     as the return value is positive, else unpredictiable.
- * The value of @outlen after return is the number of ocetes consumed.
+ *     if the return value is positive, else unpredictiable.
+ * The value of @outlen after return is the number of octets produced.
  */
 typedef int (* xmlCharEncodingOutputFunc)(unsigned char *out, int *outlen,
                                           const unsigned char *in, int *inlen);
@@ -119,7 +123,7 @@ typedef int (* xmlCharEncodingOutputFunc)(unsigned char *out, int *outlen,
 
 /*
  * Block defining the handlers for non UTF-8 encodings.
- * If iconv is supported, there is two extra fields.
+ * If iconv is supported, there are two extra fields.
  */
 
 typedef struct _xmlCharEncodingHandler xmlCharEncodingHandler;
@@ -213,38 +217,6 @@ XMLPUBFUN int XMLCALL
 					 int *outlen,
 					 const unsigned char *in,
 					 int *inlen);
-XMLPUBFUN int XMLCALL	
-	xmlGetUTF8Char			(const unsigned char *utf,
-					 int *len);
-/*
- * exports additional "UTF-8 aware" string routines which are.
- */
-
-XMLPUBFUN int XMLCALL	
-	xmlCheckUTF8			(const unsigned char *utf);
-XMLPUBFUN int XMLCALL	
-	xmlUTF8Strsize			(const xmlChar *utf,
-					 int len);
-XMLPUBFUN xmlChar * XMLCALL 
-	xmlUTF8Strndup			(const xmlChar *utf,
-					 int len);
-XMLPUBFUN xmlChar * XMLCALL 
-	xmlUTF8Strpos			(const xmlChar *utf,
-					 int pos);
-XMLPUBFUN int XMLCALL	
-	xmlUTF8Strloc			(const xmlChar *utf,
-					 const xmlChar *utfchar);
-XMLPUBFUN xmlChar * XMLCALL 
-	xmlUTF8Strsub			(const xmlChar *utf,
-					 int start,
-					 int len);
-XMLPUBFUN int XMLCALL	
-	xmlUTF8Strlen			(const xmlChar *utf);
-XMLPUBFUN int XMLCALL	
-	xmlUTF8Size			(const xmlChar *utf);
-XMLPUBFUN int XMLCALL	
-	xmlUTF8Charcmp			(const xmlChar *utf1,
-					 const xmlChar *utf2);
 #ifdef __cplusplus
 }
 #endif
